# Changelog


## 0.1.18 - 2017-12-31

* Fix retrieving financials using TTM


## 0.1.17 - 2017-09-28

* Add endpoints: financials and fundamentals


## 0.1.16 - 2017-06-07

* Fix authentication instructions in README


## 0.1.15 - 2017-02-05

* Fix ImportError of pypandoc


## 0.1.14 - 2017-01-16

* Add get to retrieve whole datasets
* Add get_page to retrieve datasets one page at a time
* Add endpoints: companies, securities, indices, prices, news
